==> dyt_sensorsdata-0.0.30.tgz: package/src/main.js <==
// 此方法兼容了vue3.0不支持require引用
const server_url = 'https://daoyitong.datasink.sensorsdata.cn/sa?token=b7cc59164b618ef1&project=production'

function callSensors (sensors, platform_type, business_channel) {
  sensors.init({
    name: 'sensors',
    server_url,
    heatmap: {
      scroll_notice_map: 'not_collect',
      get_vtrack_config: false,
    },
    is_track_single_page: true,
    use_client_time: true,
    send_type: 'beacon',
    show_log: process.env.NODE_ENV === 'development',
    app_js_bridge: true,
  });
  sensors.registerPage({
    platform_type,
    business_channel,
  });

  sensors.quick('autoTrack');
}

export const init = ({ platform_type, business_channel }) => {
  if (typeof require == 'function') {
    // 引入web SDK
    const sensors = require('./sensorsdata.es6.min').default;
    require('./event.js').cerateSa(sensors);
    callSensors(sensors, platform_type, business_channel)
  } else {
    // 引入web SDK
    import('./sensorsdata.es6.min').then(res => {
      const sensors = res.default;
      import('./event.js').then(r => {
        r.cerateSa(sensors)
        callSensors(sensors, platform_type, business_channel)
      })
    })
  }
};

// 微信小程序
export const initMiniApp = ({ platform_type, business_channel }) => {
  // 引入微信小程序 SDK
  const sensors = require('./sensorsdata.min');
  require('./event.js').cerateSa(sensors);
  // 配置初始化参数
  sensors.setPara({
    name: 'sensors',
    server_url,
    // 全埋点控制开关
    autoTrack: {
      appLaunch: false, // 默认为 true，false 则关闭 $MPLaunch 事件采集
      appShow: false, // 默认为 true，false 则关闭 $MPShow 事件采集
      appHide: false, // 默认为 true，false 则关闭 $MPHide 事件采集
      pageShow: false, // 默认为 true，false 则关闭 $MPViewScreen 事件采集
      pageShare: false, // 默认为 true，false 则关闭 $MPShare 事件采集
      mpClick: false, // 默认为 false，true 则开启 $MPClick 事件采集
      mpFavorite: false, // 默认为 true，false 则关闭 $MPAddFavorites 事件采集
    },
    // 自定义渠道追踪参数，如 source_channel: ["custom_param"]
    source_channel: [],
    // 是否允许控制台打印查看埋点数据(建议开启查看)
    show_log: true,
    // 是否允许修改 onShareAppMessage 里 return 的 path，用来增加(登录 ID，分享层级，当前的 path)，在 app onShow 中自动获取这些参数来查看具体分享来源、层级等
    allow_amend_share_path: false,
  });

  sensors.registerApp({
    platform_type,
    business_channel,
  });
  sensors.init();
};

export * from './event';

==> dyt_sensorsdata-0.0.34.tgz: package/src/main.js <==
const server_url = 'https://daoyitong.datasink.sensorsdata.cn/sa?token=b7cc59164b618ef1&project=production';
const server_uar_u = 'https://daoyitong.datasink.sensorsdata.cn/sa?token=b7cc59164b618ef1';

function callSensors (sensors, platform_type, business_channel) {
  sensors.init({
    name: 'sensors',
    server_url: process.env.NODE_ENV === 'development' ? server_uar_u : server_url,
    heatmap: {
      scroll_notice_map: 'not_collect',
      get_vtrack_config: false,
    },
    is_track_single_page: true,
    use_client_time: true,
    send_type: 'beacon',
    show_log: process.env.NODE_ENV === 'development',
    app_js_bridge: true,
  });
  sensors.registerPage({
    platform_type,
    business_channel,
  });

  sensors.quick('autoTrack');
}

export const init = ({ platform_type, business_channel }) => {
  if (typeof require == 'function') {
    // 引入web SDK
    const sensors = require('./sensorsdata.es6.min').default;
    require('./event.js').cerateSa(sensors);
    callSensors(sensors, platform_type, business_channel)
  } else {
    // 引入web SDK
    import('./sensorsdata.es6.min').then(res => {
      const sensors = res.default;
      import('./event.js').then(r => {
        r.cerateSa(sensors)
        callSensors(sensors, platform_type, business_channel)
      })
    })
  }
};

// 微信小程序
export const initMiniApp = ({ platform_type, business_channel, env }) => {
  // 引入微信小程序 SDK
  const sensors = require('./sensorsdata.min');
  require('./event.js').cerateSa(sensors);
  // 配置初始化参数
  sensors.setPara({
    name: 'sensors',
    server_url: env.includes('uat') || env.includes('development') ? server_uar_u : server_url,
    // 全埋点控制开关
    autoTrack: {
      appLaunch: false, // 默认为 true，false 则关闭 $MPLaunch 事件采集
      appShow: false, // 默认为 true，false 则关闭 $MPShow 事件采集
      appHide: false, // 默认为 true，false 则关闭 $MPHide 事件采集
      pageShow: false, // 默认为 true，false 则关闭 $MPViewScreen 事件采集
      pageShare: false, // 默认为 true，false 则关闭 $MPShare 事件采集
      mpClick: false, // 默认为 false，true 则开启 $MPClick 事件采集
      mpFavorite: false, // 默认为 true，false 则关闭 $MPAddFavorites 事件采集
    },
    // 自定义渠道追踪参数，如 source_channel: ["custom_param"]
    source_channel: [],
    // 是否允许控制台打印查看埋点数据(建议开启查看)
    show_log: true,
    // 是否允许修改 onShareAppMessage 里 return 的 path，用来增加(登录 ID，分享层级，当前的 path)，在 app onShow 中自动获取这些参数来查看具体分享来源、层级等
    allow_amend_share_path: false,
  });

  sensors.registerApp({
    platform_type,
    business_channel,
  });
  sensors.init();
};

export * from './event';
